@@ -12,9 +12,6 @@ NULL
 #' @param aesthetics A [`character`] string or vector of character
 #'  strings listing the name(s) of the aesthetic(s) that this scale works with.
 #' @details
-#'  The qualitative colour schemes are used as given (no interpolation):
-#'  colors are picked up to the maximum number of supported values.
-#'
 #'  \tabular{ll}{
 #'   **Palette** \tab **Max.** \cr
 #'   `bright` \tab 7 \cr
@@ -26,6 +23,28 @@ NULL
 #'   `dark` \tab 6 \cr
 #'   `light` \tab 9 \cr
 #'  }
+#' @section Interpolation:
+#'  The qualitative colour schemes are used as given (no interpolation):
+#'  colors are picked up to the maximum number of supported values.
+#' @inheritSection colour Qualitative colour schemes
+#' @return A [discrete][ggplot2::discrete_scale] scale.
+#' @references
+#'  Tol, P. (2021). *Colour Schemes*. SRON. Technical Note No.
+#'  SRON/EPS/TN/09-002, issue 3.2.
+#'  URL: \url{https://personal.sron.nl/~pault/data/colourschemes.pdf}
+#' @example inst/examples/ex-tol-discrete.R
+#' @family colour-blind safe colour schemes
+#' @author N. Frerebeau
+#' @name scale_tol_discrete
+#' @rdname scale_tol_discrete
+#' @keywords internal
+NULL
+
+## Bright ----------------------------------------------------------------------
+#' Paul Tol's *bright* Discrete Colour Scheme
+#'
+#' @inheritParams scale_tol_discrete
+#' @inheritSection scale_tol_discrete Interpolation
 #' @inheritSection colour Qualitative colour schemes
 #' @return A [discrete][ggplot2::discrete_scale] scale.
 #' @references
@@ -34,129 +53,181 @@ NULL
 #'  URL: \url{https://personal.sron.nl/~pault/data/colourschemes.pdf}
 #' @example inst/examples/ex-tol-discrete.R
 #' @author N. Frerebeau
-#' @family colour-blind safe colour schemes
 #' @family qualitative colour schemes
 #' @family Paul Tol's colour schemes
-#' @name scale_tol_discrete
-#' @rdname scale_tol_discrete
+#' @name scale_tol_bright
+#' @rdname scale_tol_bright
 NULL
 
-## Bright ----------------------------------------------------------------------
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_bright
 scale_colour_bright <- function(..., reverse = FALSE, aesthetics = "colour") {
   scale_discrete(aesthetics, "bright", reverse = reverse, ...)
 }
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_bright
 scale_color_bright <- scale_colour_bright
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_bright
 scale_fill_bright <- function(..., reverse = FALSE, aesthetics = "fill") {
   scale_discrete(aesthetics, "bright", reverse = reverse, ...)
 }
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_bright
 scale_edge_colour_bright <- function(..., reverse = FALSE,
                                      aesthetics = "edge_colour") {
   scale_discrete(aesthetics, "bright", reverse = reverse, ...)
 }
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_bright
 scale_edge_color_bright <- scale_edge_colour_bright
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_bright
 scale_edge_fill_bright <- function(..., reverse = FALSE,
                                    aesthetics = "edge_fill") {
   scale_discrete(aesthetics, "bright", reverse = reverse, ...)
 }
 
 ## High contrast ---------------------------------------------------------------
+#' Paul Tol's *high contrast* Discrete Colour Scheme
+#'
+#' @inheritParams scale_tol_discrete
+#' @inheritSection scale_tol_discrete Interpolation
+#' @inheritSection colour Qualitative colour schemes
+#' @return A [discrete][ggplot2::discrete_scale] scale.
+#' @references
+#'  Tol, P. (2021). *Colour Schemes*. SRON. Technical Note No.
+#'  SRON/EPS/TN/09-002, issue 3.2.
+#'  URL: \url{https://personal.sron.nl/~pault/data/colourschemes.pdf}
+#' @example inst/examples/ex-tol-discrete.R
+#' @author N. Frerebeau
+#' @family qualitative colour schemes
+#' @family Paul Tol's colour schemes
+#' @name scale_tol_highcontrast
+#' @rdname scale_tol_highcontrast
+NULL
+
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_highcontrast
 scale_colour_highcontrast <- function(..., reverse = FALSE,
                                       aesthetics = "colour") {
   scale_discrete(aesthetics, "highcontrast", reverse = reverse, ...)
 }
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_highcontrast
 scale_color_highcontrast <- scale_colour_highcontrast
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_highcontrast
 scale_fill_highcontrast <- function(..., reverse = FALSE,
                                     aesthetics = "fill") {
   scale_discrete(aesthetics, "highcontrast", reverse = reverse, ...)
 }
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_highcontrast
 scale_edge_colour_highcontrast <- function(..., reverse = FALSE,
                                            aesthetics = "edge_colour") {
   scale_discrete(aesthetics, "highcontrast", reverse = reverse, ...)
 }
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_highcontrast
 scale_edge_color_highcontrast <- scale_edge_colour_highcontrast
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_highcontrast
 scale_edge_fill_highcontrast <- function(..., reverse = FALSE,
                                          aesthetics = "edge_fill") {
   scale_discrete(aesthetics, "highcontrast", reverse = reverse, ...)
 }
 
 ## Vibrant ---------------------------------------------------------------------
+#' Paul Tol's *vibrant* Discrete Colour Scheme
+#'
+#' @inheritParams scale_tol_discrete
+#' @inheritSection scale_tol_discrete Interpolation
+#' @inheritSection colour Qualitative colour schemes
+#' @return A [discrete][ggplot2::discrete_scale] scale.
+#' @references
+#'  Tol, P. (2021). *Colour Schemes*. SRON. Technical Note No.
+#'  SRON/EPS/TN/09-002, issue 3.2.
+#'  URL: \url{https://personal.sron.nl/~pault/data/colourschemes.pdf}
+#' @example inst/examples/ex-tol-discrete.R
+#' @author N. Frerebeau
+#' @family qualitative colour schemes
+#' @family Paul Tol's colour schemes
+#' @name scale_tol_vibrant
+#' @rdname scale_tol_vibrant
+NULL
+
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_vibrant
 scale_colour_vibrant <- function(..., reverse = FALSE, aesthetics = "colour") {
   scale_discrete(aesthetics, "vibrant", reverse = reverse, ...)
 }
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_vibrant
 scale_color_vibrant <- scale_colour_vibrant
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_vibrant
 scale_fill_vibrant <- function(..., reverse = FALSE, aesthetics = "fill") {
   scale_discrete(aesthetics, "vibrant", reverse = reverse, ...)
 }
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_vibrant
 scale_edge_colour_vibrant <- function(..., reverse = FALSE,
                                       aesthetics = "edge_colour") {
   scale_discrete(aesthetics, "vibrant", reverse = reverse, ...)
 }
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_vibrant
 scale_edge_color_vibrant <- scale_edge_colour_vibrant
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_vibrant
 scale_edge_fill_vibrant <- function(..., reverse = FALSE,
                                     aesthetics = "edge_fill") {
   scale_discrete(aesthetics, "vibrant", reverse = reverse, ...)
 }
 
 ## Muted -----------------------------------------------------------------------
+#' Paul Tol's *muted* Discrete Colour Scheme
+#'
+#' @inheritParams scale_tol_discrete
+#' @inheritSection scale_tol_discrete Interpolation
+#' @inheritSection colour Qualitative colour schemes
+#' @return A [discrete][ggplot2::discrete_scale] scale.
+#' @references
+#'  Tol, P. (2021). *Colour Schemes*. SRON. Technical Note No.
+#'  SRON/EPS/TN/09-002, issue 3.2.
+#'  URL: \url{https://personal.sron.nl/~pault/data/colourschemes.pdf}
+#' @example inst/examples/ex-tol-discrete.R
+#' @author N. Frerebeau
+#' @family qualitative colour schemes
+#' @family Paul Tol's colour schemes
+#' @name scale_tol_muted
+#' @rdname scale_tol_muted
+NULL
+
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_muted
 scale_colour_muted <- function(..., reverse = FALSE, aesthetics = "colour") {
   scale_discrete(aesthetics, "muted", reverse = reverse, ...)
 }
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_muted
 scale_color_muted <- scale_colour_muted
 
 #' @export
@@ -166,160 +237,232 @@ scale_fill_muted <- function(..., reverse = FALSE, aesthetics = "fill") {
 }
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_muted
 scale_edge_colour_muted <- function(..., reverse = FALSE,
                                     aesthetics = "edge_colour") {
   scale_discrete(aesthetics, "muted", reverse = reverse, ...)
 }
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_muted
 scale_edge_color_muted <- scale_edge_colour_muted
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_muted
 scale_edge_fill_muted <- function(..., reverse = FALSE,
                                   aesthetics = "edge_fill") {
   scale_discrete(aesthetics, "muted", reverse = reverse, ...)
 }
 
 ## Medium contrast -------------------------------------------------------------
+#' Paul Tol's *medium contrast* Discrete Colour Scheme
+#'
+#' @inheritParams scale_tol_discrete
+#' @inheritSection scale_tol_discrete Interpolation
+#' @inheritSection colour Qualitative colour schemes
+#' @return A [discrete][ggplot2::discrete_scale] scale.
+#' @references
+#'  Tol, P. (2021). *Colour Schemes*. SRON. Technical Note No.
+#'  SRON/EPS/TN/09-002, issue 3.2.
+#'  URL: \url{https://personal.sron.nl/~pault/data/colourschemes.pdf}
+#' @example inst/examples/ex-tol-discrete.R
+#' @author N. Frerebeau
+#' @family qualitative colour schemes
+#' @family Paul Tol's colour schemes
+#' @name scale_tol_mediumcontrast
+#' @rdname scale_tol_mediumcontrast
+NULL
+
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_mediumcontrast
 scale_colour_mediumcontrast <- function(..., reverse = FALSE,
                                         aesthetics = "colour") {
   scale_discrete(aesthetics, "mediumcontrast", reverse = reverse, ...)
 }
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_mediumcontrast
 scale_color_mediumcontrast <- scale_colour_mediumcontrast
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_mediumcontrast
 scale_fill_mediumcontrast <- function(..., reverse = FALSE,
                                       aesthetics = "fill") {
   scale_discrete(aesthetics, "mediumcontrast", reverse = reverse, ...)
 }
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_mediumcontrast
 scale_edge_colour_mediumcontrast <- function(..., reverse = FALSE,
                                              aesthetics = "edge_colour") {
   scale_discrete(aesthetics, "mediumcontrast", reverse = reverse, ...)
 }
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_mediumcontrast
 scale_edge_color_mediumcontrast <- scale_edge_colour_mediumcontrast
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_mediumcontrast
 scale_edge_fill_mediumcontrast <- function(..., reverse = FALSE,
                                            aesthetics = "edge_fill") {
   scale_discrete(aesthetics, "mediumcontrast", reverse = reverse, ...)
 }
 
 ## Pale ------------------------------------------------------------------------
+#' Paul Tol's *pale* Discrete Colour Scheme
+#'
+#' @inheritParams scale_tol_discrete
+#' @inheritSection scale_tol_discrete Interpolation
+#' @inheritSection colour Qualitative colour schemes
+#' @return A [discrete][ggplot2::discrete_scale] scale.
+#' @references
+#'  Tol, P. (2021). *Colour Schemes*. SRON. Technical Note No.
+#'  SRON/EPS/TN/09-002, issue 3.2.
+#'  URL: \url{https://personal.sron.nl/~pault/data/colourschemes.pdf}
+#' @example inst/examples/ex-tol-discrete.R
+#' @author N. Frerebeau
+#' @family qualitative colour schemes
+#' @family Paul Tol's colour schemes
+#' @name scale_tol_pale
+#' @rdname scale_tol_pale
+NULL
+
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_pale
 scale_colour_pale <- function(..., reverse = FALSE, aesthetics = "colour") {
   scale_discrete(aesthetics, "pale", reverse = reverse, ...)
 }
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_pale
 scale_color_pale <- scale_colour_pale
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_pale
 scale_fill_pale <- function(..., reverse = FALSE, aesthetics = "fill") {
   scale_discrete(aesthetics, "pale", reverse = reverse, ...)
 }
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_pale
 scale_edge_colour_pale <- function(..., reverse = FALSE,
                                    aesthetics = "edge_colour") {
   scale_discrete(aesthetics, "pale", reverse = reverse, ...)
 }
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_pale
 scale_edge_color_pale <- scale_edge_colour_pale
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_pale
 scale_edge_fill_pale <- function(..., reverse = FALSE,
                                  aesthetics = "edge_fill") {
   scale_discrete(aesthetics, "pale", reverse = reverse, ...)
 }
 
 ## Dark ------------------------------------------------------------------------
+#' Paul Tol's *dark* Discrete Colour Scheme
+#'
+#' @inheritParams scale_tol_discrete
+#' @inheritSection scale_tol_discrete Interpolation
+#' @inheritSection colour Qualitative colour schemes
+#' @return A [discrete][ggplot2::discrete_scale] scale.
+#' @references
+#'  Tol, P. (2021). *Colour Schemes*. SRON. Technical Note No.
+#'  SRON/EPS/TN/09-002, issue 3.2.
+#'  URL: \url{https://personal.sron.nl/~pault/data/colourschemes.pdf}
+#' @example inst/examples/ex-tol-discrete.R
+#' @author N. Frerebeau
+#' @family qualitative colour schemes
+#' @family Paul Tol's colour schemes
+#' @name scale_tol_dark
+#' @rdname scale_tol_dark
+NULL
+
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_dark
 scale_colour_dark <- function(..., reverse = FALSE, aesthetics = "colour") {
   scale_discrete(aesthetics, "dark", reverse = reverse, ...)
 }
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_dark
 scale_color_dark <- scale_colour_dark
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_dark
 scale_fill_dark <- function(..., reverse = FALSE, aesthetics = "fill") {
   scale_discrete(aesthetics, "dark", reverse = reverse, ...)
 }
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_dark
 scale_edge_colour_dark <- function(..., reverse = FALSE,
                                    aesthetics = "edge_colour") {
   scale_discrete(aesthetics, "dark", reverse = reverse, ...)
 }
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_dark
 scale_edge_color_dark <- scale_edge_colour_dark
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_dark
 scale_edge_fill_dark <- function(..., reverse = FALSE,
                                  aesthetics = "edge_fill") {
   scale_discrete(aesthetics, "dark", reverse = reverse, ...)
 }
 
 ## Light -----------------------------------------------------------------------
+#' Paul Tol's *light* Discrete Colour Scheme
+#'
+#' @inheritParams scale_tol_discrete
+#' @inheritSection scale_tol_discrete Interpolation
+#' @inheritSection colour Qualitative colour schemes
+#' @return A [discrete][ggplot2::discrete_scale] scale.
+#' @references
+#'  Tol, P. (2021). *Colour Schemes*. SRON. Technical Note No.
+#'  SRON/EPS/TN/09-002, issue 3.2.
+#'  URL: \url{https://personal.sron.nl/~pault/data/colourschemes.pdf}
+#' @example inst/examples/ex-tol-discrete.R
+#' @author N. Frerebeau
+#' @family qualitative colour schemes
+#' @family Paul Tol's colour schemes
+#' @name scale_tol_light
+#' @rdname scale_tol_light
+NULL
+
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_light
 scale_colour_light <- function(..., reverse = FALSE, aesthetics = "colour") {
   scale_discrete(aesthetics, "light", reverse = reverse, ...)
 }
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_light
 scale_color_light <- scale_colour_light
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_light
 scale_fill_light <- function(..., reverse = FALSE, aesthetics = "fill") {
   scale_discrete(aesthetics, "light", reverse = reverse, ...)
 }
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_light
 scale_edge_colour_light <- function(..., reverse = FALSE,
                                     aesthetics = "edge_colour") {
   scale_discrete(aesthetics, "light", reverse = reverse, ...)
 }
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_light
 scale_edge_color_light <- scale_edge_colour_light
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_light
 scale_edge_fill_light <- function(..., reverse = FALSE,
                                   aesthetics = "edge_fill") {
   scale_discrete(aesthetics, "light", reverse = reverse, ...)
@@ -342,18 +485,37 @@ scale_edge_fill_light <- function(..., reverse = FALSE,
 #' @param aesthetics A [`character`] string or vector of character
 #'  strings listing the name(s) of the aesthetic(s) that this scale works with.
 #' @details
-#'  If more colors than defined are needed from a given scheme, the colour
-#'  coordinates are linearly interpolated to provide a continuous version of the
-#'  scheme.
-#'  Note that the default colour for `NA` can be overridden by passing
-#'  a value to [ggplot2::continuous_scale()].
-#'
 #'  \tabular{lll}{
 #'   **Palette** \tab **Max. colours** \tab **NA value** \cr
 #'   `sunset` \tab 11 \tab #FFFFFF \cr
 #'   `BuRd` \tab 9 \tab #FFEE99 \cr
 #'   `PRGn` \tab 9 \tab #FFEE99 \cr
 #'  }
+#' @section Interpolation:
+#'  If more colors than defined are needed from a given scheme, the colour
+#'  coordinates are linearly interpolated to provide a continuous version of the
+#'  scheme.
+#'
+#'  Note that the default colour for `NA` can be overridden by passing
+#'  a value to [ggplot2::continuous_scale()].
+#' @return A [continuous][ggplot2::continuous_scale] scale.
+#' @references
+#'  Tol, P. (2018). *Colour Schemes*. SRON. Technical Note No.
+#'  SRON/EPS/TN/09-002, issue 3.1.
+#'  URL: \url{https://personal.sron.nl/~pault/data/colourschemes.pdf}
+#' @example inst/examples/ex-tol-diverging.R
+#' @family colour-blind safe colour schemes
+#' @author N. Frerebeau
+#' @name scale_tol_diverging
+#' @rdname scale_tol_diverging
+#' @keywords internal
+NULL
+
+## Sunset ----------------------------------------------------------------------
+#' Paul Tol's *sunset* Diverging Colour Scheme
+#'
+#' @inheritParams scale_tol_diverging
+#' @inheritSection scale_tol_diverging Interpolation
 #' @return A [continuous][ggplot2::continuous_scale] scale.
 #' @references
 #'  Tol, P. (2018). *Colour Schemes*. SRON. Technical Note No.
@@ -361,16 +523,14 @@ scale_edge_fill_light <- function(..., reverse = FALSE,
 #'  URL: \url{https://personal.sron.nl/~pault/data/colourschemes.pdf}
 #' @example inst/examples/ex-tol-diverging.R
 #' @author N. Frerebeau
-#' @family colour-blind safe colour schemes
 #' @family diverging colour schemes
 #' @family Paul Tol's colour schemes
-#' @name scale_tol_diverging
-#' @rdname scale_tol_diverging
+#' @name scale_tol_sunset
+#' @rdname scale_tol_sunset
 NULL
 
-## Sunset ----------------------------------------------------------------------
 #' @export
-#' @rdname scale_tol_diverging
+#' @rdname scale_tol_sunset
 scale_colour_sunset <- function(..., reverse = FALSE, range = c(0, 1),
                                 midpoint = 0, discrete = FALSE,
                                 aesthetics = "colour") {
@@ -383,11 +543,11 @@ scale_colour_sunset <- function(..., reverse = FALSE, range = c(0, 1),
 }
 
 #' @export
-#' @rdname scale_tol_diverging
+#' @rdname scale_tol_sunset
 scale_color_sunset <- scale_colour_sunset
 
 #' @export
-#' @rdname scale_tol_diverging
+#' @rdname scale_tol_sunset
 scale_fill_sunset <- function(..., reverse = FALSE, range = c(0, 1),
                               midpoint = 0, discrete = FALSE,
                               aesthetics = "fill") {
@@ -400,7 +560,7 @@ scale_fill_sunset <- function(..., reverse = FALSE, range = c(0, 1),
 }
 
 #' @export
-#' @rdname scale_tol_diverging
+#' @rdname scale_tol_sunset
 scale_edge_colour_sunset <- function(..., reverse = FALSE, range = c(0, 1),
                                      midpoint = 0, discrete = FALSE,
                                      aesthetics = "edge_colour") {
@@ -413,11 +573,11 @@ scale_edge_colour_sunset <- function(..., reverse = FALSE, range = c(0, 1),
 }
 
 #' @export
-#' @rdname scale_tol_diverging
+#' @rdname scale_tol_sunset
 scale_edge_color_sunset <- scale_edge_colour_sunset
 
 #' @export
-#' @rdname scale_tol_diverging
+#' @rdname scale_tol_sunset
 scale_edge_fill_sunset <- function(..., reverse = FALSE, range = c(0, 1),
                                    midpoint = 0, discrete = FALSE,
                                    aesthetics = "edge_fill") {
@@ -430,8 +590,25 @@ scale_edge_fill_sunset <- function(..., reverse = FALSE, range = c(0, 1),
 }
 
 ## BuRd ------------------------------------------------------------------------
+#' Paul Tol's *BuRd* Diverging Colour Scheme
+#'
+#' @inheritParams scale_tol_diverging
+#' @inheritSection scale_tol_diverging Interpolation
+#' @return A [continuous][ggplot2::continuous_scale] scale.
+#' @references
+#'  Tol, P. (2018). *Colour Schemes*. SRON. Technical Note No.
+#'  SRON/EPS/TN/09-002, issue 3.1.
+#'  URL: \url{https://personal.sron.nl/~pault/data/colourschemes.pdf}
+#' @example inst/examples/ex-tol-diverging.R
+#' @author N. Frerebeau
+#' @family diverging colour schemes
+#' @family Paul Tol's colour schemes
+#' @name scale_tol_BuRd
+#' @rdname scale_tol_BuRd
+NULL
+
 #' @export
-#' @rdname scale_tol_diverging
+#' @rdname scale_tol_BuRd
 scale_colour_BuRd <- function(..., reverse = FALSE, range = c(0, 1),
                               midpoint = 0, discrete = FALSE,
                               aesthetics = "colour") {
@@ -444,11 +621,11 @@ scale_colour_BuRd <- function(..., reverse = FALSE, range = c(0, 1),
 }
 
 #' @export
-#' @rdname scale_tol_diverging
+#' @rdname scale_tol_BuRd
 scale_color_BuRd <- scale_colour_BuRd
 
 #' @export
-#' @rdname scale_tol_diverging
+#' @rdname scale_tol_BuRd
 scale_fill_BuRd <- function(..., reverse = FALSE, range = c(0, 1),
                             midpoint = 0, discrete = FALSE,
                             aesthetics = "fill") {
@@ -461,7 +638,7 @@ scale_fill_BuRd <- function(..., reverse = FALSE, range = c(0, 1),
 }
 
 #' @export
-#' @rdname scale_tol_diverging
+#' @rdname scale_tol_BuRd
 scale_edge_colour_BuRd <- function(..., reverse = FALSE, range = c(0, 1),
                                    midpoint = 0, discrete = FALSE,
                                    aesthetics = "edge_colour") {
@@ -474,11 +651,11 @@ scale_edge_colour_BuRd <- function(..., reverse = FALSE, range = c(0, 1),
 }
 
 #' @export
-#' @rdname scale_tol_diverging
+#' @rdname scale_tol_BuRd
 scale_edge_color_BuRd <- scale_edge_colour_BuRd
 
 #' @export
-#' @rdname scale_tol_diverging
+#' @rdname scale_tol_BuRd
 scale_edge_fill_BuRd <- function(..., reverse = FALSE, range = c(0, 1),
                                  midpoint = 0, discrete = FALSE,
                                  aesthetics = "edge_fill") {
@@ -491,8 +668,25 @@ scale_edge_fill_BuRd <- function(..., reverse = FALSE, range = c(0, 1),
 }
 
 ## PRGn ------------------------------------------------------------------------
+#' Paul Tol's *PRGn* Diverging Colour Scheme
+#'
+#' @inheritParams scale_tol_diverging
+#' @inheritSection scale_tol_diverging Interpolation
+#' @return A [continuous][ggplot2::continuous_scale] scale.
+#' @references
+#'  Tol, P. (2018). *Colour Schemes*. SRON. Technical Note No.
+#'  SRON/EPS/TN/09-002, issue 3.1.
+#'  URL: \url{https://personal.sron.nl/~pault/data/colourschemes.pdf}
+#' @example inst/examples/ex-tol-diverging.R
+#' @author N. Frerebeau
+#' @family diverging colour schemes
+#' @family Paul Tol's colour schemes
+#' @name scale_tol_PRGn
+#' @rdname scale_tol_PRGn
+NULL
+
 #' @export
-#' @rdname scale_tol_diverging
+#' @rdname scale_tol_PRGn
 scale_colour_PRGn <- function(..., reverse = FALSE, range = c(0, 1),
                               midpoint = 0, discrete = FALSE,
                               aesthetics = "colour") {
@@ -505,11 +699,11 @@ scale_colour_PRGn <- function(..., reverse = FALSE, range = c(0, 1),
 }
 
 #' @export
-#' @rdname scale_tol_diverging
+#' @rdname scale_tol_PRGn
 scale_color_PRGn <- scale_colour_PRGn
 
 #' @export
-#' @rdname scale_tol_diverging
+#' @rdname scale_tol_PRGn
 scale_fill_PRGn <- function(..., reverse = FALSE, range = c(0, 1),
                             midpoint = 0, discrete = FALSE,
                             aesthetics = "fill") {
@@ -522,7 +716,7 @@ scale_fill_PRGn <- function(..., reverse = FALSE, range = c(0, 1),
 }
 
 #' @export
-#' @rdname scale_tol_diverging
+#' @rdname scale_tol_PRGn
 scale_edge_colour_PRGn <- function(..., reverse = FALSE, range = c(0, 1),
                                    midpoint = 0, discrete = FALSE,
                                    aesthetics = "edge_colour") {
@@ -535,11 +729,11 @@ scale_edge_colour_PRGn <- function(..., reverse = FALSE, range = c(0, 1),
 }
 
 #' @export
-#' @rdname scale_tol_diverging
+#' @rdname scale_tol_PRGn
 scale_edge_color_PRGn <- scale_edge_colour_PRGn
 
 #' @export
-#' @rdname scale_tol_diverging
+#' @rdname scale_tol_PRGn
 scale_edge_fill_PRGn <- function(..., reverse = FALSE, range = c(0, 1),
                                  midpoint = 0, discrete = FALSE,
                                  aesthetics = "edge_fill") {
@@ -565,14 +759,7 @@ scale_edge_fill_PRGn <- function(..., reverse = FALSE, range = c(0, 1),
 #' @param discrete A [`logical`] scalar: should the colour scheme be
 #'  used as a discrete scale? If `TRUE`, it is a departure from Paul Tol's
 #'  recommendations and likely a very poor use of colour.
-#' @details
-#'  If more colors than defined are needed from a given scheme, the colour
-#'  coordinates are linearly interpolated to provide a continuous version of the
-#'  scheme, with the exception of the `discrete rainbow` scheme (see below).
-#'
-#'  Note that the default colour for `NA` can be overridden by passing
-#'  a value to [ggplot2::continuous_scale()].
-#'
+#' @details#'
 #'  \tabular{lll}{
 #'   **Palette** \tab **Max. colors** \tab **NA value** \cr
 #'   `YlOrBr` \tab 9 \tab #888888 \cr
@@ -580,6 +767,32 @@ scale_edge_fill_PRGn <- function(..., reverse = FALSE, range = c(0, 1),
 #'   `discreterainbow` \tab 23 \tab #777777 \cr
 #'   `smoothrainbow` \tab 34 \tab #666666 \cr
 #'  }
+#' @section Interpolation:
+#'  If more colors than defined are needed from a given scheme, the colour
+#'  coordinates are linearly interpolated to provide a continuous version of the
+#'  scheme, with the exception of the `discrete rainbow` scheme (see below).
+#'
+#'  Note that the default colour for `NA` can be overridden by passing
+#'  a value to [ggplot2::continuous_scale()].
+#' @inheritSection colour Rainbow colour scheme
+#' @return A [continuous][ggplot2::continuous_scale] scale.
+#' @references
+#'  Tol, P. (2018). *Colour Schemes*. SRON. Technical Note No.
+#'  SRON/EPS/TN/09-002, issue 3.1.
+#'  URL: \url{https://personal.sron.nl/~pault/data/colourschemes.pdf}
+#' @example inst/examples/ex-tol-sequential.R
+#' @family colour-blind safe colour schemes
+#' @author N. Frerebeau
+#' @name scale_tol_sequential
+#' @rdname scale_tol_sequential
+#' @keywords internal
+NULL
+
+## YlOrBr ----------------------------------------------------------------------
+#' Paul Tol's *YlOrBr* Sequential Colour Scheme
+#'
+#' @inheritParams scale_tol_sequential
+#' @inheritSection scale_tol_sequential Interpolation
 #' @inheritSection colour Rainbow colour scheme
 #' @return A [continuous][ggplot2::continuous_scale] scale.
 #' @references
@@ -588,16 +801,14 @@ scale_edge_fill_PRGn <- function(..., reverse = FALSE, range = c(0, 1),
 #'  URL: \url{https://personal.sron.nl/~pault/data/colourschemes.pdf}
 #' @example inst/examples/ex-tol-sequential.R
 #' @author N. Frerebeau
-#' @family colour-blind safe colour schemes
 #' @family sequential colour schemes
 #' @family Paul Tol's colour schemes
-#' @name scale_tol_sequential
-#' @rdname scale_tol_sequential
+#' @name scale_tol_YlOrBr
+#' @rdname scale_tol_YlOrBr
 NULL
 
-## YlOrBr ----------------------------------------------------------------------
 #' @export
-#' @rdname scale_tol_sequential
+#' @rdname scale_tol_YlOrBr
 scale_colour_YlOrBr <- function(..., reverse = FALSE, range = c(0, 1),
                                 discrete = FALSE, aesthetics = "colour") {
   if (discrete) {
@@ -609,11 +820,11 @@ scale_colour_YlOrBr <- function(..., reverse = FALSE, range = c(0, 1),
 }
 
 #' @export
-#' @rdname scale_tol_sequential
+#' @rdname scale_tol_YlOrBr
 scale_color_YlOrBr <- scale_colour_YlOrBr
 
 #' @export
-#' @rdname scale_tol_sequential
+#' @rdname scale_tol_YlOrBr
 scale_fill_YlOrBr <- function(..., reverse = FALSE, range = c(0, 1),
                               discrete = FALSE, aesthetics = "fill") {
   if (discrete) {
@@ -625,7 +836,7 @@ scale_fill_YlOrBr <- function(..., reverse = FALSE, range = c(0, 1),
 }
 
 #' @export
-#' @rdname scale_tol_diverging
+#' @rdname scale_tol_YlOrBr
 scale_edge_colour_YlOrBr <- function(..., reverse = FALSE, range = c(0, 1),
                                      discrete = FALSE,
                                      aesthetics = "edge_colour") {
@@ -638,11 +849,11 @@ scale_edge_colour_YlOrBr <- function(..., reverse = FALSE, range = c(0, 1),
 }
 
 #' @export
-#' @rdname scale_tol_diverging
+#' @rdname scale_tol_YlOrBr
 scale_edge_color_YlOrBr <- scale_edge_colour_YlOrBr
 
 #' @export
-#' @rdname scale_tol_diverging
+#' @rdname scale_tol_YlOrBr
 scale_edge_fill_YlOrBr <- function(..., reverse = FALSE, range = c(0, 1),
                                    discrete = FALSE,
                                    aesthetics = "edge_fill") {
@@ -655,8 +866,26 @@ scale_edge_fill_YlOrBr <- function(..., reverse = FALSE, range = c(0, 1),
 }
 
 ## Iridescent ------------------------------------------------------------------
+#' Paul Tol's *iridescent* Sequential Colour Scheme
+#'
+#' @inheritParams scale_tol_sequential
+#' @inheritSection scale_tol_sequential Interpolation
+#' @inheritSection colour Rainbow colour scheme
+#' @return A [continuous][ggplot2::continuous_scale] scale.
+#' @references
+#'  Tol, P. (2018). *Colour Schemes*. SRON. Technical Note No.
+#'  SRON/EPS/TN/09-002, issue 3.1.
+#'  URL: \url{https://personal.sron.nl/~pault/data/colourschemes.pdf}
+#' @example inst/examples/ex-tol-sequential.R
+#' @author N. Frerebeau
+#' @family sequential colour schemes
+#' @family Paul Tol's colour schemes
+#' @name scale_tol_iridescent
+#' @rdname scale_tol_iridescent
+NULL
+
 #' @export
-#' @rdname scale_tol_sequential
+#' @rdname scale_tol_iridescent
 scale_colour_iridescent <- function(..., reverse = FALSE, range = c(0, 1),
                                     discrete = FALSE, aesthetics = "colour") {
   if (discrete) {
@@ -668,11 +897,11 @@ scale_colour_iridescent <- function(..., reverse = FALSE, range = c(0, 1),
 }
 
 #' @export
-#' @rdname scale_tol_sequential
+#' @rdname scale_tol_iridescent
 scale_color_iridescent <- scale_colour_iridescent
 
 #' @export
-#' @rdname scale_tol_sequential
+#' @rdname scale_tol_iridescent
 scale_fill_iridescent <- function(..., reverse = FALSE, range = c(0, 1),
                                   discrete = FALSE, aesthetics = "fill") {
   if (discrete) {
@@ -684,7 +913,7 @@ scale_fill_iridescent <- function(..., reverse = FALSE, range = c(0, 1),
 }
 
 #' @export
-#' @rdname scale_tol_diverging
+#' @rdname scale_tol_iridescent
 scale_edge_colour_iridescent <- function(..., reverse = FALSE, range = c(0, 1),
                                          discrete = FALSE,
                                          aesthetics = "edge_colour") {
@@ -697,11 +926,11 @@ scale_edge_colour_iridescent <- function(..., reverse = FALSE, range = c(0, 1),
 }
 
 #' @export
-#' @rdname scale_tol_diverging
+#' @rdname scale_tol_iridescent
 scale_edge_color_iridescent <- scale_edge_colour_iridescent
 
 #' @export
-#' @rdname scale_tol_diverging
+#' @rdname scale_tol_iridescent
 scale_edge_fill_iridescent <- function(..., reverse = FALSE, range = c(0, 1),
                                        discrete = FALSE,
                                        aesthetics = "edge_fill") {
@@ -714,45 +943,81 @@ scale_edge_fill_iridescent <- function(..., reverse = FALSE, range = c(0, 1),
 }
 
 ## Discrete Rainbow ------------------------------------------------------------
+#' Paul Tol's *discrete rainbow* Sequential Colour Scheme
+#'
+#' @inheritParams scale_tol_sequential
+#' @inheritSection scale_tol_sequential Interpolation
+#' @inheritSection colour Rainbow colour scheme
+#' @return A [continuous][ggplot2::continuous_scale] scale.
+#' @references
+#'  Tol, P. (2018). *Colour Schemes*. SRON. Technical Note No.
+#'  SRON/EPS/TN/09-002, issue 3.1.
+#'  URL: \url{https://personal.sron.nl/~pault/data/colourschemes.pdf}
+#' @example inst/examples/ex-tol-sequential.R
+#' @author N. Frerebeau
+#' @family sequential colour schemes
+#' @family Paul Tol's colour schemes
+#' @name scale_tol_discreterainbow
+#' @rdname scale_tol_discreterainbow
+NULL
+
 #' @export
-#' @rdname scale_tol_sequential
+#' @rdname scale_tol_discreterainbow
 scale_colour_discreterainbow <- function(..., reverse = FALSE,
                                          aesthetics = "colour") {
   scale_discrete(aesthetics, "discreterainbow", reverse = reverse, ...)
 }
 
 #' @export
-#' @rdname scale_tol_sequential
+#' @rdname scale_tol_discreterainbow
 scale_color_discreterainbow <- scale_colour_discreterainbow
 
 #' @export
-#' @rdname scale_tol_sequential
+#' @rdname scale_tol_discreterainbow
 scale_fill_discreterainbow <- function(..., reverse = FALSE,
                                        aesthetics = "fill") {
   scale_discrete(aesthetics, "discreterainbow", reverse = reverse, ...)
 }
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_discreterainbow
 scale_edge_colour_discreterainbow <- function(..., reverse = FALSE,
                                               aesthetics = "edge_colour") {
   scale_discrete(aesthetics, "discreterainbow", reverse = reverse, ...)
 }
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_discreterainbow
 scale_edge_color_discreterainbow <- scale_edge_colour_discreterainbow
 
 #' @export
-#' @rdname scale_tol_discrete
+#' @rdname scale_tol_discreterainbow
 scale_edge_fill_discreterainbow <- function(..., reverse = FALSE,
                                             aesthetics = "edge_fill") {
   scale_discrete(aesthetics, "discreterainbow", reverse = reverse, ...)
 }
 
 ## Smooth Rainbow --------------------------------------------------------------
+#' Paul Tol's *smooth rainbow* Sequential Colour Scheme
+#'
+#' @inheritParams scale_tol_sequential
+#' @inheritSection scale_tol_sequential Interpolation
+#' @inheritSection colour Rainbow colour scheme
+#' @return A [continuous][ggplot2::continuous_scale] scale.
+#' @references
+#'  Tol, P. (2018). *Colour Schemes*. SRON. Technical Note No.
+#'  SRON/EPS/TN/09-002, issue 3.1.
+#'  URL: \url{https://personal.sron.nl/~pault/data/colourschemes.pdf}
+#' @example inst/examples/ex-tol-sequential.R
+#' @author N. Frerebeau
+#' @family sequential colour schemes
+#' @family Paul Tol's colour schemes
+#' @name scale_tol_smoothrainbow
+#' @rdname scale_tol_smoothrainbow
+NULL
+
 #' @export
-#' @rdname scale_tol_sequential
+#' @rdname scale_tol_smoothrainbow
 scale_colour_smoothrainbow <- function(..., reverse = FALSE, range = c(0, 1),
                                        discrete = FALSE, aesthetics = "colour") {
   if (discrete) {
@@ -764,11 +1029,11 @@ scale_colour_smoothrainbow <- function(..., reverse = FALSE, range = c(0, 1),
 }
 
 #' @export
-#' @rdname scale_tol_sequential
+#' @rdname scale_tol_smoothrainbow
 scale_color_smoothrainbow <- scale_colour_smoothrainbow
 
 #' @export
-#' @rdname scale_tol_sequential
+#' @rdname scale_tol_smoothrainbow
 scale_fill_smoothrainbow <- function(..., reverse = FALSE, range = c(0, 1),
                                      discrete = FALSE, aesthetics = "fill") {
   if (discrete) {
@@ -780,7 +1045,7 @@ scale_fill_smoothrainbow <- function(..., reverse = FALSE, range = c(0, 1),
 }
 
 #' @export
-#' @rdname scale_tol_diverging
+#' @rdname scale_tol_smoothrainbow
 scale_edge_colour_smoothrainbow <- function(..., reverse = FALSE, range = c(0, 1),
                                             discrete = FALSE,
                                             aesthetics = "edge_colour") {
@@ -793,11 +1058,11 @@ scale_edge_colour_smoothrainbow <- function(..., reverse = FALSE, range = c(0, 1
 }
 
 #' @export
-#' @rdname scale_tol_diverging
+#' @rdname scale_tol_smoothrainbow
 scale_edge_color_smoothrainbow <- scale_edge_colour_smoothrainbow
 
 #' @export
-#' @rdname scale_tol_diverging
+#' @rdname scale_tol_smoothrainbow
 scale_edge_fill_smoothrainbow <- function(..., reverse = FALSE, range = c(0, 1),
                                           discrete = FALSE,
                                           aesthetics = "edge_fill") {
