@@ -1,5 +1,4 @@
-# Qualitative color schemes ====================================================
-test_that("Bright", {
+test_that("Okabe Ito", {
   skip_if_not_installed("ggplot2")
   expect_s3_class(scale_colour_okabeito(), "ggproto")
   expect_s3_class(scale_colour_okabeito(), "ScaleDiscrete")
